damp11113-library
===============
A Utils library and Easy to use.

If feature in wiki haven't in library that is a preview feature. Please wait for new update.

If the library has bugs. Please new issue.

This is how to turn off check update and load all func
```py
import os

os.environ["damp11113_load_all_module"] = "NO"
os.environ["damp11113_check_update"] = "NO"
```

Installing
===============
install from PyPi

    pip install damp11113
    
or install from github

    pip install git+https://github.com/damp11113/damp11113-library.git
    
License
===============

This library use MIT License.
